# The Restless Dungeon

A Text-based dungeon adventure game.

## Installation

Clone the repo and install required dependencies:

```bash
pip install restless-dungeon
```

## Usage

Run the main file:

```bash
python3 -m restless-dungeon
```


### AI Usage

I used AI for coming up with the name for the game, writing a couple of the commit messages, and helping with debugging when my eyes couldn't find the problems.
